@@ -1,5 +1,5 @@
 package WWW::Eksi;
-$WWW::Eksi::VERSION = '0.24';
+$WWW::Eksi::VERSION = '0.25';
 =head1 NAME
 
 WWW::Eksi - Interface for Eksisozluk.com
@@ -32,6 +32,7 @@ use URI;
 use Furl;
 use Mojo::DOM;
 use WWW::Lengthen;
+use IO::Socket::SSL;
 
 use DateTime;
 use DateTime::Format::Strptime;
@@ -49,7 +50,7 @@ sub new{
     base     => 'https://www.eksisozluk.com',
     entry    => 'https://www.eksisozluk.com/entry/',
     ghebe    => 'https://www.eksisozluk.com/istatistik/gecen-haftanin-en-begenilen-entryleri',
-    strp_dt  => DateTime::Format::Strptime->new( pattern => '%d.%m.%Y%H:%M', on_error=>'croak'),
+    strp_dt  => DateTime::Format::Strptime->new( pattern => '%d.%m.%Y%H:%M'),
     strp_d   => DateTime::Format::Strptime->new( pattern => '%d.%m.%Y'),
   }, shift;
 }
@@ -129,7 +130,7 @@ sub download_entry{
                     ? $self->{strp_dt}->parse_datetime($date_posted.$time_posted)
                     : $self->{strp_d}->parse_datetime($date_posted);
   $e->{update_time} = $time_updated
-                    ? $self->{strp_dt}->parse_datetime( 
+                    ? $self->{strp_dt}->parse_datetime(
                       ($date_updated || $date_posted).$time_updated)
                     : '';
 
@@ -160,7 +161,7 @@ sub download_entry{
   return $e;
 }
 
-=head2 ghebe
+=head2 ghebe($politeness_delay)
 
 Returns an array of entries for top posts of last week.
 Ordered from more popular to less popular.
@@ -221,20 +222,20 @@ sub _process_entry{
   $e=~s/href="(https?:\/\/(goo\.gl|is\.gd)[^"]*)"/"href=\""._lengthen($1)."\""/ieg;
 
   # Make hidden references (akıllı bkz) visible
-  $e=~s/<sup class=\"ab\"><([^<]*)(data-query=\")([^>]*)\">\*<\/a><\/sup>/<$1$2$3\">\(* $3\)<\/a>/g;
+  $e=~s/(<sup class="ab"><a data-query=")([^"]*)("[^<>]*>)\*/$1$2$3* ($2)/g;
 
   # Make local links global
   $e=~s/href="\//target="_blank" href="https:\/\/eksisozluk.com\//g;
-  
+
   # Force no decoration to disable underline in Gmail
   $e=~s/href="/style="text-decoration:none;" href="/g;
-  
+
   # Add JPG to imgur images with no extension
   $e=~s/(href="https?:\/\/[^.]*\.?imgur.com\/\w{7})"/$1\.jpg"/g;
 
   # Make JPG/PNG images visible
   $e=~s/(href="([^"]*\.(jpe?g|png)(:large)?)"[^<]*<\/a>)/$1<br><br><img src="$2"><br><br>/g;
-  
+
   # Add NW arrow to external links
   $e=~s/(https?:\/\/(?!eksisozluk.com)([^\/<]*\.[^\/<]*)[^<]*<\/a>)/$1 \($2 &#8599;\)/g;
 
@@ -261,7 +262,7 @@ This software is copyright (c) 2017 by Kivanc Yazan.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-Content you reach by using this module might be subject to copyright 
+Content you reach by using this module might be subject to copyright
 terms of Eksisozluk. See eksisozluk.com for details.
 
 =cut
\ No newline at end of file
